@@ -34,4 +34,14 @@ S_CRM_LEAD_CREATE = {
             "type": "integer",
         }
     },
+    "description": {"type": "string"},
+}
+
+S_HELPDESK_TICKET_RETURN_CREATE = {
+    "id": {"type": "integer"}
+}
+
+S_HELPDESK_TICKET_CREATE = {
+    "name": {"type": "string"},
+    "description": {"type": "string"},
 }
