@@ -1,13 +1,13 @@
 import odoo
 
-from .common import BaseEMCRestCase
+from .common import BaseOnaroRestCase
 
 
-class BaseEMCRestCaseAdmin(BaseEMCRestCase):
+class BaseOnaroRestCaseAdmin(BaseOnaroRestCase):
     @classmethod
     def setUpClass(cls, *args, **kwargs):
         # Skip parent class in super to avoid recreating api key
-        super(BaseEMCRestCase, cls).setUpClass(*args, **kwargs)
+        super(BaseOnaroRestCaseAdmin, cls).setUpClass(*args, **kwargs)
         AuthApiKey = cls.env["auth.api.key"]
         admin = cls.env.ref("base.user_admin")
         cls.api_key_test = AuthApiKey.create(
